{ config, pkgs, lib, modulesPath, ... }:

{
  imports =
    [
      (modulesPath + "/virtualisation/proxmox-lxc.nix")
      ../../base.nix
      ../../common/metrics-exporters.nix

      ./services/nginx.nix
      ./services/postgresql.nix
      ./services/matrix-synapse.nix
  ];

  # Boot and console is handled by proxmoxLXC.
  boot.loader.systemd-boot.enable = lib.mkForce false; # Enabled in base.nix, forced off here.

  # Override proxmox networking
  proxmoxLXC.manageNetwork = true;
  networking = {
    hostName = "janeway";
    defaultGateway = "192.168.10.1";
    interfaces."eth0".ipv4 = {
      addresses = [
        { address = "192.168.10.183"; prefixLength = 24; }
      ];
    };
    hostId = "bed956ff";
  };

  environment.systemPackages = with pkgs; [
    vim
    bottom
  ];

  sops.defaultSopsFile = ../../secrets/janeway/janeway.yaml;

  system.stateVersion = "23.05";
}

